Wrapper to call t_coffee to calculate Transitive Consistency Score (TCS)
tcs(alignment, number_cores = 1, other_args = NULL, wd = here::here(), ...)
| alignment | Character vector of length one; the path to the input alignment |
|---|---|
| number_cores | Number of cores to use by t_coffee |
| other_args | Character vector; other arguments to pass to t_coffee. Each should be an element of the vector. |
| wd | Character vector of length one; the directory where the command will be run, and the external output written. |
| ... | Additional other arguments. Not used by this function, but meant to be used by |
A numeric value; the overall TCS score of the input alignment.
Externally, a plain text file with TCS scores for each sequence, position, and the whole alignment. The file will be named <alignment>.score_ascii, where <alignment> is the filename of the input alignment.
Chang JM, Di Tommaso P, Notredame C. TCS: a new multiple sequence alignment reliability measure to estimate alignment accuracy and improve phylogenetic tree reconstruction. Mol Biol Evol. 2014 Jun. 31(6):1625-37. http://www.tcoffee.org/Projects/tcs/
# NOT RUN { tcs("some/alignment.fasta") # }