Concatenate a list and write out the result as single file. Equivalent
of cat file1 file2.
cat_files(input_file_list, output_file)
| input_file_list | A list. Could be any list, but it's meant to used
for lists of files that have been read into R as character vectors, e.g.,
using |
|---|---|
| output_file | Path to write output file. |
A character vector of length one in the R environment; externally, the concatenated output file.
# NOT RUN { cat_files(list("a", "b", "c"), "my_list.txt") # }