Does the same thing as Yang and Smith (2014) fix_names_from_transdecoder.py, but works on one fasta file at at time.
fix_names_from_transdecoder(transdecoder_output, mol_type = "dna")
| transdecoder_output | Character vector of length one; the path to the .transdecoder.cds file produced by |
|---|---|
| mol_type | Character vector of length one; "dna" for DNA or "aa" for proteins. |
Object of class DNAbin or AAbin with names shortened to sample_code`"@"`gene
Yang, Y. and S.A. Smith. 2014. Orthology inference in non-model organisms using transcriptomes and low-coverage genomes: improving accuracy and matrix occupancy for phylogenomics. Molecular Biology and Evolution 31:3081-3092. https://bitbucket.org/yangya/phylogenomic_dataset_construction/overview
# NOT RUN { fix_names_from_transdecoder(transdecoder_output = "some/folder/CODE.transdecoder.cds") # }