Creates a directory in the working directory, and adds a hidden .keep
file. The purpose of the .keep file is to allow for tracking by
drake_plan during workflows, because
drake_plan can only track files, not folders.
make_dir(dir_name, ...)
| dir_name | Name of the directory to be created. |
|---|---|
| ... | Other arguments. Not used by this function, but meant to be used
by |
NULL in the R environment; externally, creates a
directory dir_name.
# NOT RUN { make_dir("new_dir") # }