Given a folder containing ortholog trees, write out the fasta files that correspond to the sequences in the trees.
write_ortholog_fasta_files(path_to_ys = pkgconfig::get_config("baitfindR::path_to_ys"), all_fasta, tree_folder, outdir, minimal_taxa = 4, overwrite = FALSE, get_hash = TRUE, echo = pkgconfig::get_config("baitfindR::echo", fallback = FALSE), ...)
| path_to_ys | Character vector of length one; the path to the folder containing Y&S python scripts, e.g., "/Users/me/apps/phylogenomic_dataset_construction/" |
|---|---|
| all_fasta | Character vector of length one; the path to the fasta file including all the sequences that were originally used to build the trees. |
| tree_folder | Character vector of length one; the path to the folder containing the trees to be used for extracting sequences. |
| outdir | Character vector of length one; the path to the folder where the fasta files should be written. |
| minimal_taxa | Numeric; minimal number of taxa required for output sequences to be written (regardless of ingroup/outgroup status). |
| overwrite | Logical; should previous output of this command be erased so new output can be written? Once erased it cannot be restored, so use with caution! |
| get_hash | Logical; should the 32-byte MD5 hash be computed for all fasta files concatenated together? Used for by |
| echo | Logical; should the standard output and error be printed to the screen? |
| ... | Other arguments. Not used by this function, but meant to be used by |
One fasta file per tree will be written to outdir. If get_hash is TRUE, the 32-byte MD5 hash be computed for all .fa files concatenated together will be returned.
Wrapper for Yang and Smith (2014) write_ortholog_fasta_files.py
Yang, Y. and S.A. Smith. 2014. Orthology inference in non-model organisms using transcriptomes and low-coverage genomes: improving accuracy and matrix occupancy for phylogenomics. Molecular Biology and Evolution 31:3081-3092. https://bitbucket.org/yangya/phylogenomic_dataset_construction/overview
# NOT RUN { write_ortholog_fasta_files(all_fasta = "some/folder/all.fasta", tree_folder = "some/folder/containing/tree/files", outdir = "some/folder", minimal_taxa = 5) # }